@@ -3,8 +3,6 @@ import sys, os, os.path, types, traceback, pprint
 
 DATA = 'tests/data'
 
-has_ucs4 = sys.maxunicode > 0xffff
-
 def find_test_functions(collections):
     if not isinstance(collections, list):
         collections = [collections]
@@ -12,9 +10,7 @@ def find_test_functions(collections):
     for collection in collections:
         if not isinstance(collection, dict):
             collection = vars(collection)
-        keys = collection.keys()
-        keys.sort()
-        for key in keys:
+        for key in sorted(collection):
             value = collection[key]
             if isinstance(value, types.FunctionType) and hasattr(value, 'unittest'):
                 functions.append(value)
@@ -25,13 +21,10 @@ def find_test_filenames(directory):
     for filename in os.listdir(directory):
         if os.path.isfile(os.path.join(directory, filename)):
             base, ext = os.path.splitext(filename)
-            if base.endswith('-py3'):
-                continue
-            if not has_ucs4 and base.find('-ucs4-') > -1:
+            if base.endswith('-py2'):
                 continue
             filenames.setdefault(base, []).append(ext)
-    filenames = filenames.items()
-    filenames.sort()
+    filenames = sorted(filenames.items())
     return filenames
 
 def parse_arguments(args):
@@ -58,16 +51,13 @@ def parse_arguments(args):
     return include_functions, include_filenames, verbose
 
 def execute(function, filenames, verbose):
-    if hasattr(function, 'unittest_name'):
-        name = function.unittest_name
-    else:
-        name = function.func_name
+    name = function.__name__
     if verbose:
         sys.stdout.write('='*75+'\n')
         sys.stdout.write('%s(%s)...\n' % (name, ', '.join(filenames)))
     try:
         function(verbose=verbose, *filenames)
-    except Exception, exc:
+    except Exception as exc:
         info = sys.exc_info()
         if isinstance(exc, AssertionError):
             kind = 'FAILURE'
@@ -113,7 +103,8 @@ def display(results, verbose):
         for filename in filenames:
             sys.stdout.write('-'*75+'\n')
             sys.stdout.write('%s:\n' % filename)
-            data = open(filename, 'rb').read()
+            with open(filename, 'r', errors='replace') as file:
+                data = file.read()
             sys.stdout.write(data)
             if data and data[-1] != '\n':
                 sys.stdout.write('\n')
@@ -131,9 +122,9 @@ def run(collections, args=None):
     include_functions, include_filenames, verbose = parse_arguments(args)
     results = []
     for function in test_functions:
-        if include_functions and function.func_name not in include_functions:
+        if include_functions and function.__name__ not in include_functions:
             continue
-        if function.unittest:
+        if function.unittest and function.unittest is not True:
             for base, exts in test_filenames:
                 if include_filenames and base not in include_filenames:
                     continue
